//
//  LocationView.swift
//  Trekr
//
//  Created by Paul Hudson on 22/12/2020.
//

import SwiftUI

struct LocationView: View {
    @EnvironmentObject var dataController: DataController
    @State private var showingMap = false

    let location: Location

    var body: some View {
        ScrollView {
            ZStack(alignment: .bottomTrailing) {
                Image(location.heroPicture)
                    .resizable()
                    .scaledToFit()

                if dataController.isFavorite(location) {
                    Image(systemName: "heart.fill")
                        .foregroundColor(.white)
                        .padding()
                        .background(Color.red)
                        .clipShape(Circle())
                        .overlay(
                            Circle()
                                .strokeBorder(Color.white, lineWidth: 2)
                        )
                        .offset(x: -10, y: -10)
                }
            }

            VStack(alignment: .leading) {
                Text("Country: \(location.country)")
                    .font(.title2)
                    .foregroundColor(.secondary)
                    .fontWeight(.black)
                    .textCase(.uppercase)

                Text(location.description)
                    .padding(.bottom)

                Text("Did you know?")
                    .font(.title2)
                    .foregroundColor(.secondary)
                    .fontWeight(.black)
                    .textCase(.uppercase)

                Text(location.more)
                    .padding(.bottom)

                Text("Travel advisories")
                    .font(.title2)
                    .foregroundColor(.secondary)
                    .fontWeight(.black)
                    .textCase(.uppercase)

                Text(location.advisory)

                HStack {
                    Spacer()

                    Button(dataController.isFavorite(location) ? "Remove Favorite" : "Add Favorite") {
                        dataController.toggleFavorite(location)
                    }
                    .padding()
                    .background(Color.blue)
                    .foregroundColor(.white)
                    .clipShape(Capsule())

                    Button("Show on Map") {
                        showingMap = true
                    }
                    .padding()
                    .background(Color.blue)
                    .foregroundColor(.white)
                    .clipShape(Capsule())

                    Spacer()
                }
                .padding(.bottom)
            }
            .padding(.horizontal)
        }
        .navigationTitle(location.name)
        .sheet(isPresented: $showingMap) {
            WorldView(location: location)
        }
    }
}

struct LocationView_Previews: PreviewProvider {
    static var previews: some View {
        NavigationView {
            LocationView(location: Location.example)
                .environmentObject(DataController())
        }
    }
}
